md5 : 3e12f933da55b4657c4b3ceecbb61c9d
name : Graphics::Raylib_3e12
version : ""
language : C
language_id : C
installed : 0
date_compiled : Sat Jan 14 17:31:10 2017
inline_version : 0.80
ILSM : %
    module : Inline::C
    suffix : bundle
    type : compiled
Config : %
    apiversion : ?
    archname : darwin-thread-multi-2level
    cc : /usr/bin/clang
    ccflags : -fno-common -DPERL_DARWIN -mmacosx-version-min=10.12 -pipe -Os  -fno-strict-aliasing -fstack-protector-strong -I/opt/local/include -DPERL_USE_SAFE_PUTENV
    ld : /usr/bin/clang
    osname : darwin
    osvers : 16.0.0
    so : dylib
    version : 5.24.0
